# Code organization

Folder | Purpose
---|---
`src/core_lib` | C++ code for the `core_lib` static lib with main functionality
`src/bindings_lib` | C++ code for the `shiboken` bindings
`samples/cpp` | C++ samples
`samples/python` | Python samples
`tests/cpp` | C++ tests
